@@ -19,10 +19,10 @@ void fill (Request* req, const Hash& h) {
             case 'r':
                 if      (key == "response_callback") req->response_event.add(xs::in<Request::response_fn>(v));
                 else if (key == "redirect_callback") req->redirect_event.add(xs::in<Request::redirect_fn>(v));
-                else if (key == "redirection_limit") req->redirection_limit = Simple(v);
+                else if (key == "redirection_limit") req->redirection_limit = v.number();
                 break;
             case 't':
-                if      (key == "timeout")     req->timeout = (double)Simple(v) * 1000;
+                if      (key == "timeout")     req->timeout = v.as_number<double>() * 1000;
                 else if (key == "tcp_nodelay") req->tcp_nodelay = v.is_true();
                 else if (key == "tcp_hints")   req->tcp_hints = xs::in<AddrInfoHints>(v);
                 break;
@@ -52,41 +52,41 @@ void fill (ServerResponse* res, const Hash& h) {
 }
 
 void fill (Server::Location& loc, const Hash& h) {
-    Sv sv; Simple v;
-    if ((v  = h.fetch("host")))       loc.host       = v.as_string();
-    if ((v  = h.fetch("port")))       loc.port       = v;
-    if ((v  = h.fetch("reuse_port"))) loc.reuse_port = v;
-    if ((v  = h.fetch("backlog")))    loc.backlog    = v;
-    if ((v  = h.fetch("domain")))     loc.domain     = v;
-    if ((sv = h.fetch("ssl_ctx")))    loc.ssl_ctx    = xs::in<SslContext>(sv);
+    Scalar v;
+    if ((v = h.fetch("host")))       loc.host       = v.as_string();
+    if ((v = h.fetch("port")))       loc.port       = v.number();
+    if ((v = h.fetch("reuse_port"))) loc.reuse_port = v.is_true();
+    if ((v = h.fetch("backlog")))    loc.backlog    = v.number();
+    if ((v = h.fetch("domain")))     loc.domain     = v.number();
+    if ((v = h.fetch("ssl_ctx")))    loc.ssl_ctx    = xs::in<SslContext>(v);
 
-    if ((sv = h.fetch("sock"))) {
-        auto sock = sv2sock(sv);
+    if ((v = h.fetch("sock"))) {
+        auto sock = sv2sock(v);
         if (sock) loc.sock = sock;
     }
 }
 
 void fill (Server::Config& cfg, const Hash& h) {
-    Sv sv; Simple v;
-    if ((sv = h.fetch("locations")))              cfg.locations              = xs::in<decltype(cfg.locations)>(sv);
-    if ((v  = h.fetch("idle_timeout")))           cfg.idle_timeout           = (double)v * 1000;
-    if ((v  = h.fetch("max_headers_size")))       cfg.max_headers_size       = v;
-    if ((v  = h.fetch("max_body_size")))          cfg.max_body_size          = v;
-    if ((v  = h.fetch("tcp_nodelay")))            cfg.tcp_nodelay            = v.is_true();
-    if ((v  = h.fetch("max_keepalive_requests"))) cfg.max_keepalive_requests = v;
+    Scalar v;
+    if ((v = h.fetch("locations")))              cfg.locations              = xs::in<decltype(cfg.locations)>(v);
+    if ((v = h.fetch("idle_timeout")))           cfg.idle_timeout           = v.as_number<double>() * 1000;
+    if ((v = h.fetch("max_headers_size")))       cfg.max_headers_size       = v.number();
+    if ((v = h.fetch("max_body_size")))          cfg.max_body_size          = v.number();
+    if ((v = h.fetch("tcp_nodelay")))            cfg.tcp_nodelay            = v.is_true();
+    if ((v = h.fetch("max_keepalive_requests"))) cfg.max_keepalive_requests = v.number();
 }
 
 void fill (Pool::Config& cfg, const Hash& h) {
-    Simple v;
-    if ((v = h.fetch("timeout"))) cfg.idle_timeout = (double)v * 1000;
-    if ((v = h.fetch("max_connections"))) cfg.max_connections = v;
+    Scalar v;
+    if ((v = h.fetch("timeout")))         cfg.idle_timeout    = v.as_number<double>() * 1000;
+    if ((v = h.fetch("max_connections"))) cfg.max_connections = v.number();
 }
 
 void fill (UserAgent::Config& cfg, const Hash& h) {
-    Sv sv; Simple v;
-    if ((v  = h.fetch("identity")))   cfg.identity = v.as_string();
-    if ((sv = h.fetch("ssl_ctx")))    cfg.ssl_ctx  = xs::in<SslContext>(sv);
-    if ((sv = h.fetch("proxy")))      cfg.proxy    = xs::in<URISP>(sv);
+    Scalar v;
+    if ((v = h.fetch("identity"))) cfg.identity = v.as_string();
+    if ((v = h.fetch("ssl_ctx")))  cfg.ssl_ctx  = xs::in<SslContext>(v);
+    if ((v = h.fetch("proxy")))    cfg.proxy    = xs::in<URISP>(v);
 }
 
 static bool needs_streaming(const Array& arr) noexcept {
